@@ -111,4 +111,10 @@ CString g_get_complete_path(LPCTSTR path);
 BOOL g_get_header(LPCTSTR path, CStringArray &header);
 
 // compare two path, and make relative path
-CString g_get_relative_path(LPCTSTR org_path, LPCTSTR dst_path);
\ No newline at end of file
+CString g_get_relative_path(LPCTSTR org_path, LPCTSTR dst_path);
+
+CString g_get_file_name(LPCTSTR file_path);
+
+CString g_get_file_extension(LPCTSTR file_name);
+
+CString g_get_app_tmp_file(LPCTSTR tmp_path,LPCTSTR etension);
\ No newline at end of file
